@@ -17,7 +17,7 @@ from pika.exceptions import AMQPError, AMQPConnectionError
 from pydantic import BaseModel  # pylint: disable=E0611
 from typeguard import typechecked
 
-from robotnikmq.config import RobotnikConfig, conn_params_of, config_of
+from robotnikmq.config import RobotnikConfig, config_of
 from robotnikmq.error import UnableToConnect, MalformedMessage
 from robotnikmq.utils import to_json
 
@@ -54,23 +54,28 @@ def valid_json(string: str) -> bool:
 
 class Message:
     @typechecked
-    def __init__(self, contents: Union[BaseModel, Dict[str, Any]],
-                 routing_key: Optional[str] = None,
-                 timestamp: Union[int, float, datetime, None] = None,
-                 msg_id: Union[str, UUID, None] = None):
+    def __init__(
+        self,
+        contents: Union[BaseModel, Dict[str, Any]],
+        routing_key: Optional[str] = None,
+        timestamp: Union[int, float, datetime, None] = None,
+        msg_id: Union[str, UUID, None] = None,
+    ):
         self.msg_id = msg_id or uuid()
         if not jsonable(contents):
             raise ValueError("Contents of message have to be JSON-serializeable")
         self.contents = contents.dict() if isinstance(contents, BaseModel) else contents
-        self.routing_key: str = routing_key or ''
+        self.routing_key: str = routing_key or ""
         self.timestamp: Arrow = to_arrow(timestamp) if timestamp is not None else now()
 
     @typechecked
     def to_dict(self) -> Dict[str, Any]:
-        return {'routing_key': self.routing_key,
-                'contents': self.contents,
-                'msg_id': str(self.msg_id),
-                'timestamp': self.timestamp.int_timestamp}
+        return {
+            "routing_key": self.routing_key,
+            "contents": self.contents,
+            "msg_id": str(self.msg_id),
+            "timestamp": self.timestamp.int_timestamp,
+        }
 
     @typechecked
     def to_json(self) -> str:
@@ -78,10 +83,12 @@ class Message:
 
     @staticmethod
     @typechecked
-    def of(body: str) -> 'Message':  # pylint: disable=C0103
+    def of(body: str) -> "Message":  # pylint: disable=C0103
         try:
             msg = from_json(body)
-            return Message(msg['contents'], msg['routing_key'], msg['timestamp'], msg['msg_id'])
+            return Message(
+                msg["contents"], msg["routing_key"], msg["timestamp"], msg["msg_id"]
+            )
         except (JSONDecodeError, KeyError) as exc:
             raise MalformedMessage(body) from exc
 
@@ -109,13 +116,20 @@ class Message:
 
 class Robotnik:
     @typechecked
-    def __init__(self, config: Optional[RobotnikConfig] = None,
-                 on_conn_error: ConnErrorCallback = None,
-                 config_paths: Optional[List[Path]] = None):
-        config_paths = config_paths or [Path.cwd() / 'robotnikmq.yaml',
-                                        Path.home() / '.config' / 'robotnikmq' / 'robotnikmq.yaml',
-                                        Path('/etc/robotnikmq/robotnikmq.yaml')]
-        self.config = config or config_of(first(path for path in config_paths if path.exists()))
+    def __init__(
+        self,
+        config: Optional[RobotnikConfig] = None,
+        on_conn_error: ConnErrorCallback = None,
+        config_paths: Optional[List[Path]] = None,
+    ):
+        config_paths = config_paths or [
+            Path.cwd() / "robotnikmq.yaml",
+            Path.home() / ".config" / "robotnikmq" / "robotnikmq.yaml",
+            Path("/etc/robotnikmq/robotnikmq.yaml"),
+        ]
+        self.config = config or config_of(
+            first(path for path in config_paths if path.exists())
+        )
         self._connection = None
         self._channel: Optional[BlockingChannel] = None
         self._on_conn_error = on_conn_error
@@ -126,12 +140,14 @@ class Robotnik:
         for tier in self.config.tiers:
             for config in sample(tier, len(tier)):
                 try:
-                    return BlockingConnection(conn_params_of(config))
+                    return BlockingConnection(config.conn_params())
                 except (AMQPConnectionError, SSLError) as exc:
-                    errors[f'{config.user}@{config.host}:{config.port}'] = str(exc)
+                    errors[f"{config.user}@{config.host}:{config.port}"] = str(exc)
                     if self._on_conn_error is not None:
                         self._on_conn_error(exc)
-        raise UnableToConnect(f'Cannot connect to any of the configured servers: {errors}')
+        raise UnableToConnect(
+            f"Cannot connect to any of the configured servers: {errors}"
+        )
 
     @property
     def connection(self) -> BlockingConnection:
